Sorting
=======

Some operations can have their results sorted by the value of their fields.
These helper data structures are used to define the desired order.

.. automodule:: brainframe.api.bf_codecs.sorting
   :members:
